@@ -4,7 +4,7 @@ FROM python:3.7-slim
 RUN apt-get update && apt-get install --no-install-recommends -y gcc \
     && rm -rf /var/lib/apt/lists/*
 
-RUN pip install pipenv
+RUN pip install 'pipenv==2018.11.26'
 
 WORKDIR /app
 
@@ -12,7 +12,7 @@ WORKDIR /app
 COPY Pipfile* /app/
 
 # Install project dependencies
-RUN pipenv install --system
+RUN pipenv install --deploy
 
 # Copy project files
 COPY . /app/
@@ -21,27 +21,33 @@ RUN test -e catacomb.sh && bash catacomb.sh || true
 
 ENTRYPOINT ["sh", "-c"]
 
-CMD ["python /app/server.py"]
+CMD ["pipenv run python /app/server.py"]
 """
 
 SERVER = """
 import os
 from flask import Flask, request, jsonify
-from flask_cors import CORS, cross_origin
+from flask_cors import CORS
 from system import *
 
 app = Flask(__name__)
-CORS(app, support_credentials=True)
 app.config['CORS_HEADERS'] = 'Content-Type'
+CORS(app, resources={r"/*": {"origins": "*"}})
 
 system = System()
 
-@app.route("/predict", methods=['GET', 'POST'])
-@cross_origin(supports_credentials=True)
+@app.after_request
+def after_request(response):
+  response.headers.add('Access-Control-Allow-Origin', '*')
+  response.headers.add('Access-Control-Allow-Headers', 'Content-Type,Authorization')
+  response.headers.add('Access-Control-Allow-Methods', 'GET, PUT, POST, DELETE, OPTIONS')
+  return response
+
+@app.route("/predict", methods=['POST', 'OPTIONS', 'GET'])
 def predict():
     input_object = request.get_json()['input']
     return jsonify(output=system.output(input_object))
 
 if __name__ == "__main__":
 	app.run(host="0.0.0.0", port=int(os.getenv('PORT', 5000)), debug=True)
-"""
+"""
\ No newline at end of file
